#ifndef _BSS_PDF417_READER_H_
#define _BSS_PDF417_READER_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_PDF417_DLL)
#if defined(_BSS_PDF417_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes 
*/

#define BSS_PDF417_OK               (0)
#define BSS_PDF417_NOTFOUND         (1)
#define BSS_PDF417_INVALIDARGS      (2)
#define BSS_PDF417_OUTOFMEMORY      (3)
#define BSS_PDF417_BADSYMBOL        (4)


/* 
// Structure for general barcode information
*/
typedef struct BSS_PDF417Info_Struct
{
    int                 nCenterPosX;           /* Center (X) barcode position on the image    */
    int                 nCenterPosY;           /* Center (Y) barcode position on the image    */
    int                 nDataLength;           /* Length of barcode's data (in bytes)         */
    char*               pchData;               /* Pointer to barcode's data                   */
} bssPDF417Info;


/* 
// Read PDF417 barcode symbol on the image
*/
BSS_DLL int BSS_ReadPDF417
(
    const unsigned char* pImageData,           /* Pointer to image data                       */
    int                  nImageWidth,          /* The image width                             */
    int                  nImageHeight,         /* The image height                            */
    int                  nImageRowDist,        /* Distance between image's rows (in bytes)    */
    int                  nTryReadMultiple,     /* Try to read multiple barcodes on the image  */
    bssPDF417Info**      ppPDF417Info,         /* Pointer to array with barcodes' information */
    int*                 pnPDF417InfoCount     /* Pointer to number of recognized symbol(s)   */
);

/* 
// Release allocated resources 
*/
BSS_DLL int BSS_ReleasePDF417Results
(
    bssPDF417Info*       pPDF417Info,          /* Pointer to array with barcodes' information */
    int                  nPDF417InfoCount      /* Number of items in the array                */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_PDF417_READER_H_ */
